@@ -7,7 +7,7 @@ use Fatal qw(open);
 
 our @EXPORT_OK = qw(awx_arch_file awx_install_arch_file
                     awx_install_arch_auto_file
-                    awx_arch_dir awx_install_arch_dir);
+                    awx_arch_dir awx_install_arch_dir awx_touch);
 
 sub awx_arch_file {
     my( $vol, $dir, $file ) = File::Spec->splitpath( $_[0] || '' );
@@ -39,4 +39,10 @@ sub awx_install_arch_auto_file {
                          File::Spec->splitdir( $dir ), $file );
 }
 
+sub awx_touch {
+    require ExtUtils::Command;
+    local @ARGV = @_;
+    ExtUtils::Command::touch();
+}
+
 1;
